@@ -1,8 +1,9 @@
 var NAVTREEINDEX12 =
 {
+"classzypp_1_1ChangelogEntry.html#ad5befc4d2935110b4409162bf59e2490":[4,0,7,59,3],
 "classzypp_1_1ChangelogEntry.html#ae5218daf6b6b1ce02fb8d15039dcd4a1":[3,0,10,68,7],
 "classzypp_1_1ChangelogEntry.html#ae5218daf6b6b1ce02fb8d15039dcd4a1":[4,0,7,59,7],
-"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[3,0,10,664],
+"classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[3,0,10,673],
 "classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[3,0,10,68,5],
 "classzypp_1_1ChangelogEntry.html#afb37d4888d24f154d1a9a47b83acd3db":[4,0,7,59,5],
 "classzypp_1_1CheckAccessDeleted.html":[3,0,10,69],
@@ -15,7 +16,7 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckAccessDeleted.html#a4a07dbf9ea18a007513be6524ccc9d09":[4,0,7,60,5],
 "classzypp_1_1CheckAccessDeleted.html#a4d0b49076cc3c8c435c326d6f2db8709":[3,0,10,69,11],
 "classzypp_1_1CheckAccessDeleted.html#a4d0b49076cc3c8c435c326d6f2db8709":[4,0,7,60,11],
-"classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[3,0,10,702],
+"classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[3,0,10,711],
 "classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[3,0,10,69,14],
 "classzypp_1_1CheckAccessDeleted.html#a506d3eeb6dce6618efefffb27bbbf835":[4,0,7,60,14],
 "classzypp_1_1CheckAccessDeleted.html#a5f230a616a3e858ccea2544a30f27cf9":[3,0,10,69,8],
@@ -64,7 +65,7 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#a06fd5e79ec7eb31cf9cfa2e3522d0cb3":[4,0,7,61,26],
 "classzypp_1_1CheckSum.html#a1189d7481d7020b7044be58e8a31dad3":[3,0,10,70,36],
 "classzypp_1_1CheckSum.html#a1189d7481d7020b7044be58e8a31dad3":[4,0,7,61,36],
-"classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[3,0,10,803],
+"classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[3,0,10,812],
 "classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[3,0,10,70,46],
 "classzypp_1_1CheckSum.html#a13876fe68b391a173dbafed86271ba8d":[4,0,7,61,46],
 "classzypp_1_1CheckSum.html#a14394b853d60e56b7e944f8fe07693d7":[3,0,10,70,32],
@@ -85,8 +86,8 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#a37689dd9b4adecf75b5d3799ce312cad":[4,0,7,61,50],
 "classzypp_1_1CheckSum.html#a37aadce213b9860726920f77987ad7eb":[3,0,10,70,42],
 "classzypp_1_1CheckSum.html#a37aadce213b9860726920f77987ad7eb":[4,0,7,61,42],
-"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,801],
-"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,805],
+"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,810],
+"classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,814],
 "classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,70,44],
 "classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[3,0,10,70,48],
 "classzypp_1_1CheckSum.html#a3df243927a68633bd9c3d93194d2ef07":[4,0,7,61,44],
@@ -109,7 +110,7 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#a62e775f0977b97938ce4c3898ac1a28b":[4,0,7,61,21],
 "classzypp_1_1CheckSum.html#a717983c8a9a8e0f1013041aaa8226b3a":[3,0,10,70,29],
 "classzypp_1_1CheckSum.html#a717983c8a9a8e0f1013041aaa8226b3a":[4,0,7,61,29],
-"classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[3,0,10,804],
+"classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[3,0,10,813],
 "classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[3,0,10,70,47],
 "classzypp_1_1CheckSum.html#a7b36628fa0cb43b0b3301b14daa9cc5e":[4,0,7,61,47],
 "classzypp_1_1CheckSum.html#a82b097c57c3682e29851440cb46b0260":[3,0,10,70,24],
@@ -158,8 +159,8 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CheckSum.html#ae2738a3b41c967df7f8189b9cc87d7ff":[4,0,7,61,34],
 "classzypp_1_1CheckSum.html#ae4e10150fabdf9476aa4fc07c846ba4e":[3,0,10,70,0],
 "classzypp_1_1CheckSum.html#ae4e10150fabdf9476aa4fc07c846ba4e":[4,0,7,61,0],
-"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,802],
-"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,806],
+"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,811],
+"classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,815],
 "classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,70,45],
 "classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[3,0,10,70,49],
 "classzypp_1_1CheckSum.html#af007070eec07c3396318a791c24654e5":[4,0,7,61,45],
@@ -248,6 +249,5 @@ var NAVTREEINDEX12 =
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a1240f4c074c0336cb1b4c8852f39e7d2":[4,0,7,69,0,15],
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a1f8c75ed75a90c2a030defe2a4675fb3":[3,0,10,78,0,20],
 "classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a1f8c75ed75a90c2a030defe2a4675fb3":[4,0,7,69,0,20],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a30470fad2da5684a30a8efe38d9d8139":[3,0,10,78,0,16],
-"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a30470fad2da5684a30a8efe38d9d8139":[4,0,7,69,0,16]
+"classzypp_1_1CommitPackagePreloader_1_1PreloadWorker.html#a30470fad2da5684a30a8efe38d9d8139":[3,0,10,78,0,16]
 };
