@@ -1,5 +1,7 @@
 var NAVTREEINDEX72 =
 {
+"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a92a440bf19949c595c0c6af74508b3f5":[3,0,10,43,0,23,50],
+"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a92a440bf19949c595c0c6af74508b3f5":[4,0,7,36,0,22,50],
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a97e99dcbc61c7057a7c1ee90b8c949e3":[3,0,10,43,0,23,6],
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a97e99dcbc61c7057a7c1ee90b8c949e3":[4,0,7,36,0,22,6],
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#aa1bf407f7374bf203a2930737110c7c1":[3,0,10,43,0,23,52],
@@ -247,7 +249,5 @@ var NAVTREEINDEX72 =
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#a84cb20cd01f7375231f73ba81478b16f":[3,0,10,43,0,12,1,0,1],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#a84cb20cd01f7375231f73ba81478b16f":[4,0,7,36,0,11,1,0,1],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#a9adb161c03de58890ddd7be5460a22cb":[3,0,10,43,0,12,1,0,0],
-"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#a9adb161c03de58890ddd7be5460a22cb":[4,0,7,36,0,11,1,0,0],
-"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#aa7188af8694ada671c75d44bab102115":[3,0,10,43,0,12,1,0,9],
-"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#aa7188af8694ada671c75d44bab102115":[4,0,7,36,0,11,1,0,9]
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#a9adb161c03de58890ddd7be5460a22cb":[4,0,7,36,0,11,1,0,0]
 };
