@@ -1,5 +1,9 @@
 var NAVTREEINDEX91 =
 {
+"classzyppng_1_1SyncMediaHandle.html#af97b7da81697db61ebea7108fcd0da26":[4,0,9,129,2],
+"classzyppng_1_1Timer.html":[3,0,13,170],
+"classzyppng_1_1Timer.html":[4,0,9,132],
+"classzyppng_1_1Timer.html#a11bb7c203c840939bd3ceb744fee56ef":[3,0,13,170,13],
 "classzyppng_1_1Timer.html#a11bb7c203c840939bd3ceb744fee56ef":[4,0,9,132,13],
 "classzyppng_1_1Timer.html#a1654093ec9bacd0985091322b1482c5a":[3,0,13,170,3],
 "classzyppng_1_1Timer.html#a1654093ec9bacd0985091322b1482c5a":[4,0,9,132,3],
@@ -245,9 +249,5 @@ var NAVTREEINDEX91 =
 "classzyppng_1_1WorkerCaps.html#ad4481358c39ce9bfea621d0cd002e1dc":[4,0,9,143,22],
 "classzyppng_1_1WorkerCaps.html#adb4dd61ccb3049067d090e93bc20f980":[3,0,13,181,17],
 "classzyppng_1_1WorkerCaps.html#adb4dd61ccb3049067d090e93bc20f980":[4,0,9,143,17],
-"classzyppng_1_1WorkerCaps.html#aeaace097c6b00f245dc4f4fc0349f6ca":[3,0,13,181,21],
-"classzyppng_1_1WorkerCaps.html#aeaace097c6b00f245dc4f4fc0349f6ca":[4,0,9,143,21],
-"classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[3,0,13,181,15],
-"classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[4,0,9,143,15],
-"classzyppng_1_1WorkerCaps.html#afde2fc3fe969cc1975ad3f6e35a4a89a":[3,0,13,181,14]
+"classzyppng_1_1WorkerCaps.html#aeaace097c6b00f245dc4f4fc0349f6ca":[3,0,13,181,21]
 };
