@@ -1,5 +1,7 @@
 var NAVTREEINDEX92 =
 {
+"classzyppng_1_1WorkerCaps.html#aeaace097c6b00f245dc4f4fc0349f6ca":[4,0,9,143,21],
+"classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[3,0,13,181,15],
 "classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[4,0,9,143,15],
 "classzyppng_1_1WorkerCaps.html#afde2fc3fe969cc1975ad3f6e35a4a89a":[3,0,13,181,14],
 "classzyppng_1_1WorkerCaps.html#afde2fc3fe969cc1975ad3f6e35a4a89a":[4,0,9,143,14],
@@ -247,7 +249,5 @@ var NAVTREEINDEX92 =
 "classzyppng_1_1worker_1_1DeviceDriver.html":[4,0,9,6,4],
 "classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[3,0,13,44,4,12],
 "classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[4,0,9,6,4,12],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[3,0,13,44,4,8],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[4,0,9,6,4,8],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a0be42c0d96bd73b23323d1d3cb0f9fef":[3,0,13,44,4,18]
+"classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[3,0,13,44,4,8]
 };
