@@ -1,5 +1,9 @@
 var NAVTREEINDEX95 =
 {
+"functions_type_m.html":[4,3,3,11],
+"functions_type_n.html":[4,3,3,12],
+"functions_type_o.html":[4,3,3,13],
+"functions_type_p.html":[4,3,3,14],
 "functions_type_q.html":[4,3,3,15],
 "functions_type_r.html":[4,3,3,16],
 "functions_type_s.html":[4,3,3,17],
@@ -245,9 +249,5 @@ var NAVTREEINDEX95 =
 "mtry_8h.html":[5,0,1,6,5,5],
 "mtry_8h_source.html":[5,0,1,6,5,5],
 "namespaceKeyRingWorkflow.html":[3,0,4],
-"namespaceboost.html":[3,0,0],
-"namespaceboost_1_1logic.html":[3,0,0,0],
-"namespacehelix.html":[3,0,1],
-"namespacehelix_1_1detail.html":[3,0,1,0],
-"namespacehelix_1_1detail.html#a12176d4cfa53562b43599c27fe9f062b":[3,0,1,0,4]
+"namespaceboost.html":[3,0,0]
 };
